import _MuiThemeProvider from "@material-ui/core/styles/MuiThemeProvider";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import JssProvider from 'react-jss/lib/JssProvider';
import hoistStatics from 'hoist-non-react-statics';
import getContext from '../util/getContext';
import getDisplayName from '../util/getDisplayName';
/**
 * inject Mui Theme
 * @param {object} theme
 */

const withMuiTheme = theme => BaseComponent => {
  class InjectMuiTheme extends PureComponent {
    // wrap displayName for easier debug
    constructor(props) {
      super(props);

      _defineProperty(this, "pageContext", null);

      this.pageContext = props.pageContext || getContext(theme);
    }

    componentDidMount() {
      // Remove the server-side injected CSS.
      const jssStyles = document.querySelector('#jss-server-side');

      if (jssStyles && jssStyles.parentNode) {
        jssStyles.parentNode.removeChild(jssStyles);
      }
    }

    render() {
      // eslint-disable-next-line react/destructuring-assignment
      const pageContext = this.props.pageContext || this.pageContext;
      return React.createElement(JssProvider, {
        registry: pageContext.sheetsRegistry,
        generateClassName: pageContext.generateClassName
      }, React.createElement(_MuiThemeProvider, {
        theme: pageContext.theme,
        sheetsManager: pageContext.sheetsManager
      }, React.createElement(BaseComponent, _extends({}, this.props, {
        pageContext: pageContext
      }))));
    }

  }

  _defineProperty(InjectMuiTheme, "displayName", `withMuiTheme(${getDisplayName(BaseComponent)})`);

  InjectMuiTheme.propTypes = {
    pageContext: PropTypes.object
  };
  InjectMuiTheme.defaultProps = {
    pageContext: null
  }; // hoist all static functions

  hoistStatics(InjectMuiTheme, BaseComponent);
  return InjectMuiTheme;
};

export default withMuiTheme;