function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import PropTypes from 'prop-types';
import { Head, Main, NextScript } from 'next/document';
import getContext from '../util/getContext';
import getDisplayName from '../util/getDisplayName';
/**
 * Enable material-ui in nextjs._document.
 * DocumentComponent: next/document.
 * @param {MUITheme} theme
 * @param {next/document} DocumentComponent
 */

const extendsWithMui = theme => DocumentComponent => {
  class ExtendsWithMui extends DocumentComponent {
    static async getInitialProps(ctx) {
      // Resolution order
      //
      // On the server:
      // 1. app.getInitialProps
      // 2. page.getInitialProps
      // 3. document.getInitialProps
      // 4. app.render
      // 5. page.render
      // 6. document.render
      //
      // On the server with error:
      // 1. document.getInitialProps
      // 2. app.render
      // 3. page.render
      // 4. document.render
      //
      // On the client
      // 1. app.getInitialProps
      // 2. page.getInitialProps
      // 3. app.render
      // 4. page.render
      const superProps = await super.getInitialProps(ctx); // inject theme by hoc

      let pageContext;
      const page = ctx.renderPage(Component => {
        const WrappedComponent = props => {
          // eslint-disable-next-line react/destructuring-assignment
          pageContext = props.pageContext || getContext(theme);
          return React.createElement(Component, _extends({}, props, {
            pageContext: pageContext
          }));
        };

        WrappedComponent.propTypes = {
          pageContext: PropTypes.object
        };
        WrappedComponent.defaultProps = {
          pageContext: null
        };
        return WrappedComponent;
      });
      const {
        head
      } = superProps;

      if (pageContext != null) {
        const jssStyles = React.createElement("style", {
          id: "jss-server-side",
          key: "jss-server-side-key",
          dangerouslySetInnerHTML: {
            __html: pageContext.sheetsRegistry.toString()
          }
        });
        head.push(jssStyles);
      }

      return _objectSpread({}, superProps, page, {
        head,
        pageContext
      });
    }

    render() {
      const {
        pageContext
      } = this.props;
      return React.createElement("html", {
        lang: "en"
      }, React.createElement(Head, null, React.createElement("meta", {
        charSet: "utf-8"
      }), React.createElement("meta", {
        name: "viewport",
        content: "minimum-scale=1, initial-scale=1, width=device-width, shrink-to-fit=no"
      }), React.createElement("meta", {
        name: "theme-color",
        content: pageContext.theme.palette.primary.main
      }), React.createElement("link", {
        rel: "stylesheet",
        href: "https://fonts.googleapis.com/css?family=Roboto:300,400,500"
      })), React.createElement("body", null, React.createElement(Main, null), React.createElement(NextScript, null)));
    }

  }

  _defineProperty(ExtendsWithMui, "displayName", `extendsWithMui(${getDisplayName(DocumentComponent)})`);

  return ExtendsWithMui;
};

export default extendsWithMui;